<!--
SPDX-FileCopyrightText: 2023 Anthony Zimmermann

SPDX-License-Identifier: GPL-2.0-only
-->

<!-- PHOTOASSISTANT_INTRODUCTION_SECTION_START -->
# PhotoAssistant
![Image](photoassistant/photoassistant-icon.png)

Welcome to PhotoAssistant, an application designed to help you efficiently organize your photos for long-term storage. Whether you prefer to store your photos locally or use a syncing feature to keep them in an organized storage solution of your choice, PhotoAssistant aims to simplify the process and eliminate unnecessary user interactions.

## Features

PhotoAssistant offers the following key features:

- **Organize your photos quickly and effortless for a long-term storage**
- **View all your photos in a single, comprehensive view**
- **Fast detail view in a single separate window connected to your preview selection**
- **Customizable preview photo size**
- **Stay focused on selecting and sorting photos while PhotoAssistant takes care of the rest**

In addition to its organizing capabilities, PhotoAssistant also functions as an image viewer with special features:

- **Tagging**: Tag your photos to easily filter and search for specific photos later.
- **Interactive presentation**: Utilize the separate detail view window to present photos interactively to an audience.

---

## Why Should You Use PhotoAssistant?

You may wonder why you should choose PhotoAssistant over standard file explorers and image viewers for organizing your photos. Here are some common issues with traditional tools:

1. **Navigating directories**: Standard file explorers require you to navigate through multiple directories to drag and drop your photos, making the process time-consuming and cumbersome. PhotoAssistant navigates entirely for you, you only need to define where your Collection is and which photos you want to work on.
2. **View photos in detail**: Viewing photos selectively in higher resolution is tedious, as every single image loads slowly or opens in a separate window, disrupting your workflow. PhotoAssistant provides an internal photo viewer updating the photos you select fast and seamlessly.
3. **Preview photos with reasonable detail**: The preview photos in a file explorer are often too small or too large to make meaningful decisions or observations. PhotoAssistant allows you to customize the preview photo size according to your needs to observe your photos.
4. **Thumbnail images pollute the storage**: Most applications working with many photos store thumbnail versions of them on your disk to improve the application speed. PhotoAssistant does not do this while still being decently fast.
5. **Keep photos untouched**: Other applications dealing with image data might silently modify the meta data or the actual image data of your photos irreversible. If you don't believe it, I recommend you to search for "Is a photo viewer rotation lossless?" to start with. PhotoAssistant is designed to only move your data within memory and avoids any other modifications. Your photos are precious and PhotoAssistant recognizes this to the extend that it does not even modify the meta data of your photos as well.

PhotoAssistant provides you with an efficient and enjoyable photo organizing experience addressing the above mentioned issues. It concentrates on doing exactly what you need without creating unwanted side-effects.

---

## Can I Stop Using PhotoAssistant at Any Time?

Absolutely! PhotoAssistant is specifically designed to solely help you in organizing your photos as a collection of files which potentially will be compatible with computers forever. If you decide to stop using PhotoAssistant, simply continue using the photos within your Collections considering them as photos within a directory. PhotoAssistant only moves your photos and manages modified or additional meta information in separate `.meta` files. You can simply delete the `.meta` files if you wish to do so. Deleted `.meta` files do not confuse PhotoAssistant as well, even though the data stored in them can not be retrieved after deletion.

---

## What are `.meta` Files For?

You might notice the presence of `.meta` files next to your photos after using PhotoAssistant. These files are created based on your user interactions and contain human-readable JSON data. They store information such as file movements, added tags, and corrected rotation information. While these files are not essential, deleting them will result in PhotoAssistant losing information connected to your photos. The `.meta` files are on purpose not hidden such that you can share the `.meta` files along with your photos, helping others benefit from the stored information when using PhotoAssistant. Feel free to reuse the JSON data for your own purposes if you are experienced in handling JSON files. Every block of meta data is associated with an image by the checksum computed via the well known SHA-256 algorithm.
<!-- PHOTOASSISTANT_INTRODUCTION_SECTION_END -->
---
<!-- GETTING_STARTED_SECTION_START -->
# Getting Started

## 1. Create/Open a Collection

To get started with PhotoAssistant, you need to create/open a Collection. Follow these steps:

1. Click on "File" in the menu bar.
2. Select "Create Collection" or "Open Collection" according to your needs and choose a directory.

A Collection is essentially a directory to organize your photos inside. Applying main tags to photos will integrate these into your Collection. You can create a Collection on your local drive or an external drive or USB stick. If you're new to PhotoAssistant, you'll need to create a Collection before proceeding.
Collections can not be nested as photos can not be organized in two Collections at the same time.

## 2. Open Photos

Once you have a Collection set up, you are ready to open photos for viewing and/or organizing. To open photos, follow these steps:

1. Click on "File" in the menu bar.
2. Select "Open Photos" and select a directory containing photos.

You can open photos from any directory of your local drive or external drives/USB sticks.
Opening photos works only with a Collection set up as PhotoAssistant requires one to fullfill user interactions on opened photos like applying main tags.

## 3. Start Organizing Your Photos

Now that you have your photos visualized in PhotoAssistant, you can start organizing them. Here are some useful tips:

- **Move photos in or within your Collection**: Use the main tags feature to easily organize your photos. Main tags are essentially tags that start with a colon. Simply type a main tag into the right panel, and PhotoAssistant will organize a corresponding directory within your Collection for you. Applying a main tag will finally move the photo to the designated directory. You can create nested directories by adding additional colons (e.g., ":2023:vacation:beach").
- **Add tags**: Add additional tags to your photos to make filtering and searching easier. Type tags into the right panel or select from existing ones using the dropdown menu. Apply the tags by clicking the "Apply Tags" button or using the shortcut `CTRL+<TAG-GROUP-ID>`. The currently applied tags will appear in the "Tags" box below.
- **Delete tags**: Delete tags by clicking on the tag to be deleted in the "Tags" box on the bottom right and press `DELETE`.
- **Enlarge photos**: Conveniently open photos in a separate detail view window by double-clicking, pressing `ENTER` or `RETURN`. Feel free to resize the window as desired, granting you the opportunity for a closer and more thorough examination of every photo.
- **Delete photos**: Delete a photo by pressing `CTRL+DELETE` or `CTRL+BACKSPACE`. Deleted photos are usually only moved into a directory named "deleted" within your collection. It is up to you to delete this folder later when you are sure about your choices. The directory with deleted images is ignored when opening images.
- **Adjust preview photos size**: Zoom the photo grid using <!-- QKeySequence.StandardKey.ZoomIn_START -->`CTRL+PLUS` (\*)<!-- QKeySequence.StandardKey.ZoomIn_END --> or <!-- QKeySequence.StandardKey.ZoomOut_START -->`CTRL+MINUS` (\*)<!-- QKeySequence.StandardKey.ZoomOut_END -->.
- **Rotate photos**: Rotate a photo by pressing `CTRL+R`.
- **Filtering and sorting**: Use the "View Control" panel to sort your photos or filter them based on specific tags including main tags. Sort your photos by selecting an option from the "Sort By" dropdown menu. To filter your photos, type tags in the filter rules area and click the "Apply Tag Filters" button.
- **Integrate photos into Collection**: Click on "Integrate Photos Into Collection" in the the "File" menu.

(\*) Maybe deviates depending on platform.
<!-- GETTING_STARTED_SECTION_END -->
---
<!-- QUICK_REFERENCE_SECTION_START -->
# Quick Reference

**Create/Open a Collection**

- Click on "File" in the menu bar, select "Create Collection" or "Open Collection" from the dropdown menu.

**Open Photos**

- Click on "File" in the menu bar, select "Open Photos" from the dropdown menu.

**Move photos into/within your Collection**

- Tag your photo with a main tag. A main tag is a tag starting with a colon (e.g., ":2023:vacation:beach").

**Add tags**

- Setup tags in the panel on the right. Apply the tags by clicking the "Apply Tags" button or using the shortcut `CTRL+<TAG-GROUP-ID>`.


**Delete tags**

- Clicking on the tag to be deleted in the "Tags" box on the bottom right and press `DELETE`.

**Enlarge photos**

- Double-click, press `ENTER` or `RETURN` on a photo to open it in a separate detail view window.

**Delete photos**

- Delete a photo by pressing `CTRL+DELETE` or `CTRL+BACKSPACE`. Deleted photos are usually only moved into a directory named "deleted" within your collection. It is up to you to delete this folder later when you are sure about your choices. The directory with deleted images is ignored when opening images.

**Adjust preview photos size**

- Zoom the photo grid using <!-- QKeySequence.StandardKey.ZoomIn_START -->`CTRL+PLUS` (\*)<!-- QKeySequence.StandardKey.ZoomIn_END --> or <!-- QKeySequence.StandardKey.ZoomOut_START -->`CTRL+MINUS` (\*)<!-- QKeySequence.StandardKey.ZoomOut_END -->.

**Rotate photo**

- Rotate a photo by pressing `CTRL+R`.

**Filtering and sorting**

- Use the "View Control" panel.
- Sort your photos by selecting an option from the "Sort By" dropdown menu.  
- Filter your photos by typings tags in the filter rules area and click the "Apply Tag Filters" button. The star character * allows matching any sequence of characters.

**Integrate photos into Collection or clean Collection up**

- Click on "Integrate Photos Into Collection" in the the "File" menu. This operation deletes duplicate photos, cleans up meta data and integrates photos into the Collection

(\*) Maybe deviates depending on platform.
<!-- QUICK_REFERENCE_SECTION_END -->
---
<!-- SETTINGS_SECTION_START -->
# Settings

Settings are currently only supported by manually editing a text file located in the root directory of your Collection. Look for a file named `"collection.config"`.
Make sure to backup the file before making any modifications to ensure that you can always restore it if yoyu get stuck. Do not modify the first line defining a version!

There are currently two settings supported:

**`deleted_photos_folder`**:  
Specify the name of a directory where deleted photos are moved into. The value `""` makes PhotoAssistant delete your photos **irretrievable** meaning that they will not be moved into any folder instead. A value different from `""` will leave it up to the user to actually delete these photos when desired by deleting the entire directory. (Default value: `"deleted"`)

**`tagged_photos_root_folder`**:  
Specify a name for a directory to put photos into when a main tag is applied. The value `""` refers to the Collection root directory. Any other value will instruct PhotoAssistant to use a separate subdirectory within the Collection to organize photos with main tags. (Default value: `""`)

<!-- SETTINGS_SECTION_END -->
---
<!-- ABOUT_SECTION_START -->
# PhotoAssistant Version 1.0.2<!-- VERSION -->
![Image](photoassistant/photoassistant-icon.png)

```

```

**Helps you view and organize your photos for long-term storage. Simple, fast, effective.**

```

```

[PhotoAssistant](https://gitlab.com/AnthonyZimmermann/photoassistant) is released under the terms of GNU General Public License v2.0 only.  
**PhotoAssistant comes with ABSOLUTELY NO WARRANTY.**

*Copyright 2023 Anthony Zimmermann*

```





```

```
GNU GENERAL PUBLIC LICENSE
Version 2, June 1991

Copyright (C) 1989, 1991 Free Software Foundation, Inc.
51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.

Preamble

The licenses for most software are designed to take away your freedom to share and change it. By contrast, the GNU General Public License is intended to guarantee your freedom to share and change free software--to make sure the software is free for all its users. This General Public License applies to most of the Free Software Foundation's software and to any other program whose authors commit to using it. (Some other Free Software Foundation software is covered by the GNU Lesser General Public License instead.) You can apply it to your programs, too.

When we speak of free software, we are referring to freedom, not price. Our General Public Licenses are designed to make sure that you have the freedom to distribute copies of free software (and charge for this service if you wish), that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs; and that you know you can do these things.

To protect your rights, we need to make restrictions that forbid anyone to deny you these rights or to ask you to surrender the rights. These restrictions translate to certain responsibilities for you if you distribute copies of the software, or if you modify it.

For example, if you distribute copies of such a program, whether gratis or for a fee, you must give the recipients all the rights that you have. You must make sure that they, too, receive or can get the source code. And you must show them these terms so they know their rights.

We protect your rights with two steps: (1) copyright the software, and (2) offer you this license which gives you legal permission to copy, distribute and/or modify the software.

Also, for each author's protection and ours, we want to make certain that everyone understands that there is no warranty for this free software. If the software is modified by someone else and passed on, we want its recipients to know that what they have is not the original, so that any problems introduced by others will not reflect on the original authors' reputations.

Finally, any free program is threatened constantly by software patents. We wish to avoid the danger that redistributors of a free program will individually obtain patent licenses, in effect making the program proprietary. To prevent this, we have made it clear that any patent must be licensed for everyone's free use or not licensed at all.

The precise terms and conditions for copying, distribution and modification follow.

TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION

0. This License applies to any program or other work which contains a notice placed by the copyright holder saying it may be distributed under the terms of this General Public License. The "Program", below, refers to any such program or work, and a "work based on the Program" means either the Program or any derivative work under copyright law: that is to say, a work containing the Program or a portion of it, either verbatim or with modifications and/or translated into another language. (Hereinafter, translation is included without limitation in the term "modification".) Each licensee is addressed as "you".

Activities other than copying, distribution and modification are not covered by this License; they are outside its scope. The act of running the Program is not restricted, and the output from the Program is covered only if its contents constitute a work based on the Program (independent of having been made by running the Program). Whether that is true depends on what the Program does.

1. You may copy and distribute verbatim copies of the Program's source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice and disclaimer of warranty; keep intact all the notices that refer to this License and to the absence of any warranty; and give any other recipients of the Program a copy of this License along with the Program.

You may charge a fee for the physical act of transferring a copy, and you may at your option offer warranty protection in exchange for a fee.

2. You may modify your copy or copies of the Program or any portion of it, thus forming a work based on the Program, and copy and distribute such modifications or work under the terms of Section 1 above, provided that you also meet all of these conditions:

     a) You must cause the modified files to carry prominent notices stating that you changed the files and the date of any change.

     b) You must cause any work that you distribute or publish, that in whole or in part contains or is derived from the Program or any part thereof, to be licensed as a whole at no charge to all third parties under the terms of this License.

     c) If the modified program normally reads commands interactively when run, you must cause it, when started running for such interactive use in the most ordinary way, to print or display an announcement including an appropriate copyright notice and a notice that there is no warranty (or else, saying that you provide a warranty) and that users may redistribute the program under these conditions, and telling the user how to view a copy of this License. (Exception: if the Program itself is interactive but does not normally print such an announcement, your work based on the Program is not required to print an announcement.)

These requirements apply to the modified work as a whole. If identifiable sections of that work are not derived from the Program, and can be reasonably considered independent and separate works in themselves, then this License, and its terms, do not apply to those sections when you distribute them as separate works. But when you distribute the same sections as part of a whole which is a work based on the Program, the distribution of the whole must be on the terms of this License, whose permissions for other licensees extend to the entire whole, and thus to each and every part regardless of who wrote it.

Thus, it is not the intent of this section to claim rights or contest your rights to work written entirely by you; rather, the intent is to exercise the right to control the distribution of derivative or collective works based on the Program.

In addition, mere aggregation of another work not based on the Program with the Program (or with a work based on the Program) on a volume of a storage or distribution medium does not bring the other work under the scope of this License.

3. You may copy and distribute the Program (or a work based on it, under Section 2) in object code or executable form under the terms of Sections 1 and 2 above provided that you also do one of the following:

     a) Accompany it with the complete corresponding machine-readable source code, which must be distributed under the terms of Sections 1 and 2 above on a medium customarily used for software interchange; or,

     b) Accompany it with a written offer, valid for at least three years, to give any third party, for a charge no more than your cost of physically performing source distribution, a complete machine-readable copy of the corresponding source code, to be distributed under the terms of Sections 1 and 2 above on a medium customarily used for software interchange; or,

     c) Accompany it with the information you received as to the offer to distribute corresponding source code. (This alternative is allowed only for noncommercial distribution and only if you received the program in object code or executable form with such an offer, in accord with Subsection b above.)

The source code for a work means the preferred form of the work for making modifications to it. For an executable work, complete source code means all the source code for all modules it contains, plus any associated interface definition files, plus the scripts used to control compilation and installation of the executable. However, as a special exception, the source code distributed need not include anything that is normally distributed (in either source or binary form) with the major components (compiler, kernel, and so on) of the operating system on which the executable runs, unless that component itself accompanies the executable.

If distribution of executable or object code is made by offering access to copy from a designated place, then offering equivalent access to copy the source code from the same place counts as distribution of the source code, even though third parties are not compelled to copy the source along with the object code.

4. You may not copy, modify, sublicense, or distribute the Program except as expressly provided under this License. Any attempt otherwise to copy, modify, sublicense or distribute the Program is void, and will automatically terminate your rights under this License. However, parties who have received copies, or rights, from you under this License will not have their licenses terminated so long as such parties remain in full compliance.

5. You are not required to accept this License, since you have not signed it. However, nothing else grants you permission to modify or distribute the Program or its derivative works. These actions are prohibited by law if you do not accept this License. Therefore, by modifying or distributing the Program (or any work based on the Program), you indicate your acceptance of this License to do so, and all its terms and conditions for copying, distributing or modifying the Program or works based on it.

6. Each time you redistribute the Program (or any work based on the Program), the recipient automatically receives a license from the original licensor to copy, distribute or modify the Program subject to these terms and conditions. You may not impose any further restrictions on the recipients' exercise of the rights granted herein. You are not responsible for enforcing compliance by third parties to this License.

7. If, as a consequence of a court judgment or allegation of patent infringement or for any other reason (not limited to patent issues), conditions are imposed on you (whether by court order, agreement or otherwise) that contradict the conditions of this License, they do not excuse you from the conditions of this License. If you cannot distribute so as to satisfy simultaneously your obligations under this License and any other pertinent obligations, then as a consequence you may not distribute the Program at all. For example, if a patent license would not permit royalty-free redistribution of the Program by all those who receive copies directly or indirectly through you, then the only way you could satisfy both it and this License would be to refrain entirely from distribution of the Program.

If any portion of this section is held invalid or unenforceable under any particular circumstance, the balance of the section is intended to apply and the section as a whole is intended to apply in other circumstances.

It is not the purpose of this section to induce you to infringe any patents or other property right claims or to contest validity of any such claims; this section has the sole purpose of protecting the integrity of the free software distribution system, which is implemented by public license practices. Many people have made generous contributions to the wide range of software distributed through that system in reliance on consistent application of that system; it is up to the author/donor to decide if he or she is willing to distribute software through any other system and a licensee cannot impose that choice.

This section is intended to make thoroughly clear what is believed to be a consequence of the rest of this License.

8. If the distribution and/or use of the Program is restricted in certain countries either by patents or by copyrighted interfaces, the original copyright holder who places the Program under this License may add an explicit geographical distribution limitation excluding those countries, so that distribution is permitted only in or among countries not thus excluded. In such case, this License incorporates the limitation as if written in the body of this License.

9. The Free Software Foundation may publish revised and/or new versions of the General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.

Each version is given a distinguishing version number. If the Program specifies a version number of this License which applies to it and "any later version", you have the option of following the terms and conditions either of that version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of this License, you may choose any version ever published by the Free Software Foundation.

10. If you wish to incorporate parts of the Program into other free programs whose distribution conditions are different, write to the author to ask for permission. For software which is copyrighted by the Free Software Foundation, write to the Free Software Foundation; we sometimes make exceptions for this. Our decision will be guided by the two goals of preserving the free status of all derivatives of our free software and of promoting the sharing and reuse of software generally.

NO WARRANTY

11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.

12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

END OF TERMS AND CONDITIONS

How to Apply These Terms to Your New Programs

If you develop a new program, and you want it to be of the greatest possible use to the public, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.

To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively convey the exclusion of warranty; and each file should have at least the "copyright" line and a pointer to where the full notice is found.

     one line to give the program's name and an idea of what it does. Copyright (C) yyyy name of author

     This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.

     This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

     You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. Also add information on how to contact you by electronic and paper mail.

If the program is interactive, make it output a short notice like this when it starts in an interactive mode:

     Gnomovision version 69, Copyright (C) year name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w'. This is free software, and you are welcome to redistribute it under certain conditions; type `show c' for details.

The hypothetical commands `show w' and `show c' should show the appropriate parts of the General Public License. Of course, the commands you use may be called something other than `show w' and `show c'; they could even be mouse-clicks or menu items--whatever suits your program.

You should also get your employer (if you work as a programmer) or your school, if any, to sign a "copyright disclaimer" for the program, if necessary. Here is a sample; alter the names:

     Yoyodyne, Inc., hereby disclaims all copyright interest in the program `Gnomovision' (which makes passes at compilers) written by James Hacker.

signature of Ty Coon, 1 April 1989 Ty Coon, President of Vice
```
<!-- ABOUT_SECTION_END -->
